/*
 * test-lexer.c
 *
 * Copyright 1998, 1999 Michael Elizabeth Chastain, <mailto:mec@shout.net>.
 * Licensed under the Gnu Public License, Version 2.
 *
 * Small main program to test the lexical analyzer.
 */

#include <stdio.h>
#include <string.h>

#include "mconfig.h"
#include "parser.tab.h"

int parser_magic_cookie  = 0;
int parser_error_count   = 0;
int parser_warning_count = 0;
YYSTYPE yylval;

argument_type argument;



int main( int argc, const char * argv [] )
{
    int iarg;
    int token;

    argument.cmdname = argv [0];

    for ( iarg = argc - 1; iarg > 0; --iarg )
    {
	const char * error_string;

	if ( input_push_file( argv [iarg], &error_string ) < 0 )
	    error_exit( error_string );
    }

    while ( ( token = yylex( ) ) != 0 )
    {
	switch ( token )
	{
	default:		printf( "<%d> ", token		); break;

	case '"':
	case '$': case ';':
	case '[': case ']':
	case '!': case '=':	printf( "%c ", token		); break;

	case '\n':		printf( "NL\n"			); break;

	case SOURCE:		printf( "SOURCE "		); break;

	case MAINMENU_OPTION:	printf( "MAINMENU_OPTION "	); break;
	case ENDMENU:		printf( "ENDMENU "		); break;

	case MAINMENU_NAME:	printf( "MAINMENU_NAME "	); break;
	case COMMENT:		printf( "COMMENT "		); break;
	case TEXT:		printf( "TEXT "			); break;

	case UNSET:		printf( "UNSET "		); break;

	case ASK_BOOL:		printf( "ASK_BOOL "		); break;
	case ASK_HEX:		printf( "ASK_HEX "		); break;
	case ASK_INT:		printf( "ASK_INT "		); break;
	case ASK_STRING:	printf( "ASK_STRING "		); break;
	case ASK_TRISTATE:	printf( "ASK_TRISTATE "		); break;

	case DEF_BOOL:		printf( "DEF_BOOL "		); break;
	case DEF_HEX:		printf( "DEF_HEX "		); break;
	case DEF_INT:		printf( "DEF_INT "		); break;
	case DEF_STRING:	printf( "DEF_STRING "		); break;
	case DEF_TRISTATE:	printf( "DEF_TRISTATE "		); break;

	case DEP_BOOL:		printf( "DEP_BOOL "		); break;
	case DEP_HEX:		printf( "DEP_HEX "		); break;
	case DEP_INT:		printf( "DEP_INT "		); break;
	case DEP_STRING:	printf( "DEP_STRING "		); break;
	case DEP_TRISTATE:	printf( "DEP_TRISTATE "		); break;

	case CHOICE:		printf( "CHOICE "		); break;
	case NCHOICE:		printf( "NCHOICE "		); break;

	case IF:		printf( "IF "			); break;
	case THEN:		printf( "THEN "			); break;
	case ELSE:		printf( "ELSE "			); break;
	case FI:		printf( "FI "			); break;
	case DASH_O:		printf( "DASH_O "		); break;
	case DASH_A:		printf( "DASH_A "		); break;

	case LEXEME:
	    if ( yylval.value_lexeme.squote )
		printf( "'" );
	    printf( ".%.*s.",
		yylval.value_lexeme.piece.len, yylval.value_lexeme.piece.ptr );
	    if ( yylval.value_lexeme.squote )
		printf( "'" );
	    printf( " " );
	    break;

	case ISNOTSET:
	    printf( "# .%.*s. is not set ",
		yylval.value_lexeme.piece.len, yylval.value_lexeme.piece.ptr );
	    break;
	}
    }

    return 0;
}
